| rmet_example | R Documentation |
A dataset containing one year of hourly meteorological observations from the automatic station A801 (Porto Alegre, RS), downloaded from INMET.
rmet_example
A data frame with columns as returned by inmet_read().
See ?inmet_read for the full variable reference.
INMET – Instituto Nacional de Meteorologia
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.